# cpro
### Automate your C/C++ workflow
The goal of cpro is to help you
 focus on the development process. 
 cpro will observe your C/C++ project and adds missing files to the cmake environment automatically.

`hier kommen die bilder`

## Getting Started
### Installation
To get started
1. install python in version 3 or higher
2. install pip
3. `pip install cpro`


